@@ -11,13 +11,12 @@
 
 namespace Predis\Command;
 
-use Predis\Helpers;
-
 /**
  * @link http://redis.io/commands/srem
+ *
  * @author Daniele Alessandri <suppakilla@gmail.com>
  */
-class SetRemove extends PrefixableCommand
+class SetRemove extends Command
 {
     /**
      * {@inheritdoc}
@@ -30,8 +29,8 @@ class SetRemove extends PrefixableCommand
     /**
      * {@inheritdoc}
      */
-    protected function filterArguments(Array $arguments)
+    protected function filterArguments(array $arguments)
     {
-        return Helpers::filterVariadicValues($arguments);
+        return self::normalizeVariadic($arguments);
     }
 }
